@@ -9,10 +9,27 @@
 # | disclosure restricted by GSA ADP Schedule Contract with IBM Corp. |
 # +-------------------------------------------------------------------+
 """Test the use of a generator to build an observable"""
-from typing import Iterator
+from typing import Iterator, List
 from contextlib import contextmanager
 from rx_utils import from_iterable_factory
-from rx.operators import take
+import rx.operators as op
+
+
+def test_iterator():
+
+    data = ('a', 'b', 'c')
+
+    result = list()
+
+    def add_to_list(dst: List[str], item: str) -> List[str]:
+        dst.append(item)
+        return dst
+
+    obs = from_iterable_factory(lambda: data).pipe(op.take(2), op.reduce(add_to_list, result))
+    obs.subscribe()
+
+    assert len(result) == 2
+    assert result == ['a', 'b']
 
 
 def test_generator():
@@ -36,7 +53,7 @@ def test_generator():
             yield 2
             yield 3
 
-    obs = from_iterable_factory(my_generator).pipe(take(2))
+    obs = from_iterable_factory(my_generator).pipe(op.take(2))
 
     obs.subscribe()
 
